==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/RepositoryCore/src/com/clustercontrol/repository/action/ModifyNodeProperty.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.bean.Property;
import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.repository.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;
import com.clustercontrol.util.PropertyUtil;

/**
 * ΡɤѹʤɤԤ饹Ǥ
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class ModifyNodeProperty {

    // ----- instance ᥽å ----- //

    /**
     * ꤷΡɤˤĤơ°ѹԤޤ
     * 
     * @param property
     *            °
     * @return ѹ硢true
     */
    public boolean edit(Property property) {
        PropertyUtil.deletePropertyDefine(property);

        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        try {
            repository.modifyNode(property);
            return true;
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// ʤξ硢顼ɽ
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (NamingException e) {
        } catch (FinderException e) {
        } catch (CreateException e) {
        }
        return false;
    }

    /**
     * ꤷפ°ƤΥΡɤˤĤơ°ѹԤޤ
     * 
     * @param property
     * @param facilityId
     * @return
     */
    public boolean editAllInScope(Property property, String facilityId) {
        PropertyUtil.deletePropertyDefine(property);

        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        try {
            repository.modifyNode(property, facilityId);
            return true;
        } catch (RemoteException e) {
        } catch (NamingException e) {
        } catch (FinderException e) {
        }
        return false;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/RepositoryCore/src/com/clustercontrol/repository/action/ModifyNodeProperty.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.bean.Property;
import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.repository.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;
import com.clustercontrol.util.PropertyUtil;

/**
 * ノードの変更などを行うクラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class ModifyNodeProperty {

    // ----- instance メソッド ----- //

    /**
     * 指定したノードについて、属性の変更を行います。
     * 
     * @param property
     *            属性情報
     * @return 変更に成功した場合、true
     */
    public boolean edit(Property property) {
        PropertyUtil.deletePropertyDefine(property);

        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        try {
            repository.modifyNode(property);
            return true;
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (NamingException e) {
        } catch (FinderException e) {
        } catch (CreateException e) {
        }
        return false;
    }

    /**
     * 指定したスコープに属する全てのノードについて、属性の変更を行います。
     * 
     * @param property
     * @param facilityId
     * @return
     */
    public boolean editAllInScope(Property property, String facilityId) {
        PropertyUtil.deletePropertyDefine(property);

        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        try {
            repository.modifyNode(property, facilityId);
            return true;
        } catch (RemoteException e) {
        } catch (NamingException e) {
        } catch (FinderException e) {
        }
        return false;
    }
}
